<?php declare(strict_types=1);

use ILIAS\GlobalScreen\Scope\Tool\Provider\AbstractDynamicToolPluginProvider;

/**
 * Class FormATestGlobalScreenToolsProvider
 * @author Michael Jansen <mjansen@databay.de>
 */
class FormATestGlobalScreenToolsProvider extends AbstractDynamicToolPluginProvider
{
    public const LEFT_NAV = 'left_nav';

    /**
     * @inheritDoc
     */
    public function isInterestedInContexts() : \ILIAS\GlobalScreen\ScreenContext\Stack\ContextCollection
    {
        return $this->context_collection->main()->administration();
    }

    /**
     * @inheritDoc
     */
    public function getToolsForContextStack(\ILIAS\GlobalScreen\ScreenContext\Stack\CalledContexts $called_contexts) : array
    {
        $iff = function ($id) {
            return $this->identification_provider->contextAwareIdentifier($id);
        };
        $l = function (string $content) {
            return $this->dic->ui()->factory()->legacy($content);
        };

        $tools = [];

        $additionalData = $called_contexts->getLast()->getAdditionalData();
        if ($additionalData->exists(self::LEFT_NAV)) {
            $leftNav = $additionalData->get(self::LEFT_NAV);

            $title = $this->plugin->txt('questions_overview_title');
            $icon = $this->dic->ui()->factory()->symbol()->icon()->custom(
                ilFormATestPlugin::_getIcon('xtsf', 'small'),
                $this->plugin->txt('questions_overview_title')
            );

            $tools[] = $this->factory
                ->tool($iff('FormATest|Navi'))
                ->withTitle($title)
                ->withSymbol($icon)
                ->withContentWrapper(static function () use ($l, $leftNav) {
                    return $l($leftNav);
                });
        }

        return $tools;
    }
}
